# 0.1.3 (2014-11-10)

Added two formatting functions: only_digits and with_dash

# 0.1.2 (2014-10-25)

Support for company kennitala.

Fixed control digit computation - according to [Icelandic wiki entry on kennitala](https://is.wikipedia.org/wiki/Kennitala).

Fixed validation for people born in 1800s

# 0.1.1 (2014-10-22)

Changed version number for easier installation with pip (without --pre or explicit version number.)

# 0.1.0b First release (2014-10-22)
